#ifndef SAVEDIALOG_H
#define SAVEDIALOG_H

#include <QDialog>

namespace Ui {
    class saveDialog;
}

class saveDialog : public QDialog
{
    Q_OBJECT

    friend class wpNew;

public:
    explicit saveDialog(QWidget *parent = 0);
    ~saveDialog();

protected:
    Ui::saveDialog *ui;
};

#endif // SAVEDIALOG_H
